@@ -51,11 +51,33 @@ Classes
 The loader and dumper classes expose a number of attributes that can be
 customised to tweak their behaviour.
 
+Supported datatypes
+===================
+
+There is support for:
+    * Basic python types (int, str, bool, float, NoneType)
+    * NamedTuple
+    * Enum
+    * Optional[SomeType]
+    * List[SomeType]
+    * Dict[TypeA, TypeB]
+    * Tuple[TypeA, TypeB, TypeC]
+    * Tuple[SomeType, ...]
+    * Set[SomeType]
+    * Union[TypeA, TypeB]
+    * ForwardRef
+    * Literal
+    * Dataclass
+    * attrs
+    * TypedDict
+    * datetime
+    * Path
+    * IPv4Address, IPv6Address
+
 Handlers
 ========
 
-An important way to tweak the behaviour of a loader or dumper object is
-to modify the handlers list.
+To work with other datatypes, handlers can be used.
 
 The handlers' list items are tuples for two functions. The signatures are
 different for loader or dumper.
@@ -125,9 +147,15 @@ The dictionary key for 'attribute' will be 'att.rib.ute:name'.
 This is very useful for keys that use invalid or reserved characters that
 can't be used in variable names.
 Another common application is to convert camelCase into not_camel_case.
+
+It is implemented this way to avoid doing automatic name translations,
+that might introduce surprises.
+
+To use a metadata key different than 'name', set the mangle_key parameter
+to the loader/dumper.
 """
 
-# Copyright (C) 2018-2019 Salvo "LtWorf" Tomaselli
+# Copyright (C) 2018-2021 Salvo "LtWorf" Tomaselli
 #
 # typedload is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
