@@ -203,6 +203,7 @@ class Loader:
             (lambda type_: type_ in self.strconstructed, _strconstructload),
             (is_attrs, _attrload),
             (is_any, _anyload),
+            (is_newtype, _newtypeload),
         ]  # type: List[Tuple[Callable[[Any], bool], Callable[[Loader, Any, Type], Any]]]
 
         for k, v in kwargs.items():
@@ -458,6 +459,8 @@ def _dataclassload(l: Loader, value: Dict[str, Any], type_) -> Any:
         value = _mangle_names(transforms, value, l.failonextra)
     except ValueError as e:
         raise TypedloadValueError(str(e), value=value, type_=type_)
+    except AttributeError as e:
+        raise TypedloadAttributeError(str(e), value=value, type_=type_)
 
     return _objloader(l, fields, necessary_fields, type_hints, value, type_)
 
@@ -479,6 +482,9 @@ def _dictequivalence(l: Loader, value: Any) -> Dict:
 
 
 def _objloader(l: Loader, fields: Set[str], necessary_fields: Set[str], type_hints, value: Dict[str, Any], type_) -> Any:
+    '''
+    Helper function to load dict-like data into an object.
+    '''
     try:
         vfields = set(value.keys())
     except AttributeError as e:
@@ -500,19 +506,19 @@ def _objloader(l: Loader, fields: Set[str], necessary_fields: Set[str], type_hin
             type_=type_,
         )
 
-    fieldsdiff = vfields.difference(fields)
-    if l.failonextra and len(fieldsdiff):
-        extra = ', '.join(fieldsdiff)
-        raise TypedloadValueError(
-            'Dictionary has unrecognized fields: %s and cannot be loaded into %s' % (extra, tname(type_)),
-            value=value,
-            type_=type_,
-        )
-
     params = {}
     for k, v in value.items():
         if k not in fields:
-            continue
+            # Field in value is not in the type
+            if l.failonextra:
+                extra = ', '.join(vfields.difference(fields))
+                raise TypedloadValueError(
+                    'Dictionary has unrecognized fields: %s and cannot be loaded into %s' % (extra, tname(type_)),
+                    value=value,
+                    type_=type_,
+                )
+            else:
+                continue
         params[k] = l.load(
             v,
             type_hints[k],
@@ -567,26 +573,19 @@ def _unionload(l: Loader, value, type_) -> Any:
 
     If no suitable type is found, an exception is raised.
     """
-    try:
-        args = uniontypes(type_)
-    except AttributeError:
-        raise TypedloadAttributeError('The typing API for this Python version is unknown', type_=type_, value=value)
+    args = uniontypes(type_)
 
     value_type = type(value)
 
     # Do not convert basic types, if possible
-    if value_type in args.intersection(l.basictypes):
+    if value_type in l.basictypes and value_type in args:
         return value
 
     exceptions = []
 
     # Give a score to the types
-    sorted_args = []  # type: List[Type]
-    for t in args:
-        if t not in l.basictypes:
-            sorted_args.insert(0, t)
-        else:
-            sorted_args.append(t)
+    sorted_args = list(args)  # type: List[Type]
+    sorted_args.sort(key=lambda i: i in l.basictypes)
 
     # Try all types
     loaded_count = 0
@@ -598,7 +597,7 @@ def _unionload(l: Loader, value, type_) -> Any:
             if not l.uniondebugconflict:
                 # Do not try more if we are not debugging
                 break
-        except Exception as e:
+        except TypedloadException as e:
             exceptions.append(e)
 
     if loaded_count == 1:
@@ -697,6 +696,8 @@ def _attrload(l, value, type_):
         value = _mangle_names(namesmap, value, l.failonextra)
     except ValueError as e:
         raise TypedloadValueError(str(e), value=value, type_=type_)
+    except AttributeError as e:
+        raise TypedloadAttributeError(str(e), value=value, type_=type_)
 
     return _objloader(l, fields, necessary_fields, type_hints, value, type_)
 
@@ -713,3 +714,7 @@ def _strconstructload(l: Loader, value, type_):
         raise TypedloadTypeError(str(e), type_=type_, value=value)
     except Exception as e:
         raise TypedloadException(str(e), type_=type, value=value)
+
+
+def _newtypeload(l: Loader, value, type_):
+    return l.load(value, type_.__supertype__)
