@@ -31,9 +31,9 @@ different versions of Python.
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 # author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
-
+import sys
 from enum import Enum
-from typing import Any, Tuple, Union, Set, List, Dict, Type, FrozenSet
+from typing import Any, Tuple, Union, Set, List, Dict, Type, FrozenSet, NewType
 
 
 __all__ = [
@@ -52,6 +52,7 @@ __all__ = [
     'is_tuple',
     'is_union',
     'is_typeddict',
+    'is_newtype',
     'uniontypes',
     'literalvalues',
     'NONETYPE',
@@ -199,22 +200,24 @@ def is_attrs(type_: Type[Any]) -> bool:
     return hasattr(type_, '__attrs_attrs__')
 
 
-def uniontypes(type_: Type[Any]) -> Set[Type[Any]]:
+if sys.version_info > (3, 10, 0):
+    def is_newtype(type_: Type[Any]) -> bool:
+        return type(type_) == NewType
+
+else:
+    def is_newtype(type_: Type[Any]) -> bool:
+        return hasattr(type_, '__supertype__')
+
+
+def uniontypes(type_: Type[Any]) -> Tuple[Type[Any], ...]:
     '''
     Returns the types of a Union.
-
-    Raises ValueError if the argument is not a Union
-    and AttributeError when running on an unsupported
-    Python version.
     '''
-    if not is_union(type_):
-        raise ValueError('Not a Union: ' + str(type_))
-
-    if hasattr(type_, '__args__'):
-        return set(type_.__args__)
-    elif hasattr(type_, '__union_params__'):
-        return set(type_.__union_params__)
-    raise AttributeError('The typing API for this Python version is unknown')
+    types = getattr(type_, '__args__', None)
+    if types is not None:
+        return types
+    else:
+        return type_.__union_params__
 
 
 def literalvalues(type_: Type[Any]) -> Set[Any]:
@@ -232,7 +235,7 @@ def is_literal(type_: Type[Any]) -> bool:
     '''
     Check if the type is a typing.Literal
     '''
-    return getattr(type_, '__origin__', None) == Literal and Literal != None
+    return getattr(type_, '__origin__', None) == Literal and Literal is not None
 
 
 def is_typeddict(type_: Type[Any]) -> bool:
